Distributed to Paid-In Capital (DPI) is a term used to measure the total
capital that a private equity fund has returned thus far to its investors. It
is also referred to as the realisation multiple. The DPI value is the
cumulative value of all investor distributions expressed as a multiple of all
the capital paid into the fund up to that time.

Formula: DPI = Cumulative Distributions / Paid-In Capital

See also:
- <https://www.moonfare.com/glossary/distributed-to-paid-in-capital-dpi>
- <https://www.investopedia.com/terms/r/realization_multiple.asp>
